@@ -92,7 +92,10 @@ centre <- center
 #' @export
 center.default <- function(x, verbose = TRUE, ...) {
   if (isTRUE(verbose)) {
-    message(insight::format_message(sprintf("Centering currently not possible for variables of class '%s'.", class(x)[1])))
+    message(insight::format_message(
+      sprintf("Centering currently not possible for variables of class `%s`.", class(x)[1]),
+      "You may open an issue at https://github.com/easystats/datawizard/issues."
+    ))
   }
   x
 }
@@ -168,9 +171,16 @@ center.data.frame <- function(x,
                               append = FALSE,
                               ignore_case = FALSE,
                               verbose = TRUE,
+                              regex = FALSE,
                               ...) {
   # evaluate select/exclude, may be select-helpers
-  select <- .select_nse(select, x, exclude, ignore_case, verbose = verbose)
+  select <- .select_nse(select,
+    x,
+    exclude,
+    ignore_case,
+    regex = regex,
+    verbose = verbose
+  )
 
   # process arguments
   args <- .process_std_args(x, select, exclude, weights, append,
@@ -214,9 +224,16 @@ center.grouped_df <- function(x,
                               append = FALSE,
                               ignore_case = FALSE,
                               verbose = TRUE,
+                              regex = FALSE,
                               ...) {
   # evaluate select/exclude, may be select-helpers
-  select <- .select_nse(select, x, exclude, ignore_case, verbose = verbose)
+  select <- .select_nse(select,
+    x,
+    exclude,
+    ignore_case,
+    regex = regex,
+    verbose = verbose
+  )
 
   args <- .process_grouped_df(x, select, exclude, append,
     append_suffix = "_c",
