@@ -197,10 +197,9 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
     id <- make.unique(c(all_columns, id), sep = "_")[length(all_columns) + 1]
     # and also tell user...
     if (isTRUE(verbose)) {
-      warning(
-        insight::format_message(sprintf("Value of `id` already exists as column name. ID column was renamed to `%s`.", id)),
-        call. = FALSE
-      )
+      warning(insight::format_message(
+        sprintf("Value of `id` already exists as column name. ID column was renamed to `%s`.", id)
+      ), call. = FALSE)
     }
   }
 
@@ -221,16 +220,25 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
     # If not all column names specified in "by" are present, yield warning
     # and use all shared column names
     if (!all(by %in% colnames(x)) || !all(by %in% colnames(y))) {
+      missing_in_x <- setdiff(by, colnames(x))
+      missing_in_y <- setdiff(by, colnames(y))
+      stop_message <- c(
+        "Not all columns specified in `by` were found in the data frames.",
+        if (length(missing_in_x) > 0) {
+          paste0("Following columns are in `by` but absent in `x`: ", text_concatenate(missing_in_x))
+        },
+        if (length(missing_in_y) > 0) {
+          paste0("Following columns are in `by` but absent in `y`: ", text_concatenate(missing_in_y))
+        }
+      )
       if (isTRUE(verbose)) {
-        warning(
+        stop(
           insight::format_message(
-            "Not all columns specified in `by` were found in the data frames.",
-            "Using all columns that are present in both data frames."
+            stop_message
           ),
           call. = FALSE
         )
       }
-      by <- intersect(colnames(x), colnames(y))
     }
 
     # if still both data frames have no common columns, do a full join
@@ -254,7 +262,12 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
   # check valid combination of "join" and "by" -----------------------
 
   if (join %in% c("anti", "semi") && (is.null(by) || length(by) != 1)) {
-    stop(insight::format_message(sprintf("For `join = \"%s\"`, `by` needs to be a name of only one variable that is present in both data frames.", join)), call. = FALSE)
+    stop(insight::format_message(
+      sprintf(
+        "For `join = \"%s\"`, `by` needs to be a name of only one variable that is present in both data frames.",
+        join
+      )
+    ), call. = FALSE)
   }
 
 
@@ -263,10 +276,10 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
   # for later sorting
   if (join != "bind") {
     if (nrow(x) > 0) {
-      x$.data_merge_id_x <- 1:nrow(x)
+      x$.data_merge_id_x <- seq_len(nrow(x))
     }
     if (nrow(y) > 0) {
-      y$.data_merge_id_y <- (1:nrow(y)) + nrow(x)
+      y$.data_merge_id_y <- (seq_len(nrow(y))) + nrow(x)
     }
   }
   all_columns <- union(colnames(x), colnames(y))
@@ -343,10 +356,9 @@ data_merge.list <- function(x, join = "left", by = NULL, id = NULL, verbose = TR
       id <- make.unique(c(colnames(out), id), sep = "_")[length(colnames(out)) + 1]
       # and also tell user...
       if (isTRUE(verbose)) {
-        warning(
-          insight::format_message(sprintf("Value of `id` already exists as column name. ID column was renamed to `%s`.", id)),
-          call. = FALSE
-        )
+        warning(insight::format_message(
+          sprintf("Value of `id` already exists as column name. ID column was renamed to `%s`.", id)
+        ), call. = FALSE)
       }
     }
     out[[id]] <- df_id
@@ -364,7 +376,7 @@ data_merge.list <- function(x, join = "left", by = NULL, id = NULL, verbose = TR
   } else {
     # add ID for merging
     if (nrow(x) > 0) {
-      x$.data_merge_row <- 1:nrow(x)
+      x$.data_merge_row <- seq_len(nrow(x))
     }
     if (nrow(y) > 0) {
       y$.data_merge_row <- (nrow(x) + 1):(nrow(x) + nrow(y))
