@@ -45,8 +45,15 @@ reverse_scale <- reverse
 #' @export
 reverse.default <- function(x, verbose = TRUE, ...) {
   if (isTRUE(verbose)) {
-    message(insight::format_message(paste0("Variables of class '", class(x)[1], "' can't be recoded and remain unchanged.")))
+    message(insight::format_message(
+      paste0(
+        "Variables of class '",
+        class(x)[1],
+        "' can't be recoded and remain unchanged."
+      )
+    ))
   }
+
   x
 }
 
@@ -131,6 +138,8 @@ reverse.grouped_df <- function(x,
                                exclude = NULL,
                                range = NULL,
                                ignore_case = FALSE,
+                               regex = FALSE,
+                               verbose = FALSE,
                                ...) {
   info <- attributes(x)
 
@@ -138,7 +147,13 @@ reverse.grouped_df <- function(x,
   grps <- attr(x, "groups", exact = TRUE)
 
   # evaluate arguments
-  select <- .select_nse(select, x, exclude, ignore_case)
+  select <- .select_nse(select,
+    x,
+    exclude,
+    ignore_case,
+    regex = regex,
+    verbose = verbose
+  )
 
   # dplyr < 0.8.0?
   if (is.null(grps)) {
@@ -172,9 +187,17 @@ reverse.data.frame <- function(x,
                                exclude = NULL,
                                range = NULL,
                                ignore_case = FALSE,
+                               regex = FALSE,
+                               verbose = FALSE,
                                ...) {
   # evaluate arguments
-  select <- .select_nse(select, x, exclude, ignore_case)
+  select <- .select_nse(select,
+    x,
+    exclude,
+    ignore_case,
+    regex = regex,
+    verbose = verbose
+  )
 
   # Transform the range so that it is a list now
   if (!is.null(range)) {
