@@ -16,8 +16,6 @@
 #' @param ... not used.
 #' @inheritParams find_columns
 #'
-#' @inheritSection center Selection of variables - the `select` argument
-#'
 #' @return A data frame, or a list of data frames, with one frequency table
 #' as data frame per variable.
 #'
@@ -78,7 +76,7 @@ data_tabulate.default <- function(x, drop_levels = FALSE, name = NULL, verbose =
   freq_table <- tryCatch(table(addNA(x)), error = function(e) NULL)
 
   if (is.null(freq_table)) {
-    warning(paste0("Can't compute frequency tables for objects of class '", class(x)[1], "'."), call. = FALSE)
+    warning(paste0("Can't compute frequency tables for objects of class `", class(x)[1], "`."), call. = FALSE)
     return(NULL)
   }
 
@@ -130,12 +128,19 @@ data_tabulate.data.frame <- function(x,
                                      select = NULL,
                                      exclude = NULL,
                                      ignore_case = FALSE,
+                                     regex = FALSE,
                                      collapse = FALSE,
                                      drop_levels = FALSE,
                                      verbose = TRUE,
                                      ...) {
   # evaluate arguments
-  select <- .select_nse(select, x, exclude, ignore_case)
+  select <- .select_nse(select,
+    x,
+    exclude,
+    ignore_case,
+    regex = regex,
+    verbose = verbose
+  )
   out <- lapply(select, function(i) {
     data_tabulate(x[[i]], drop_levels = drop_levels, name = i, verbose = verbose, ...)
   })
@@ -152,6 +157,7 @@ data_tabulate.grouped_df <- function(x,
                                      select = NULL,
                                      exclude = NULL,
                                      ignore_case = FALSE,
+                                     regex = FALSE,
                                      verbose = TRUE,
                                      collapse = FALSE,
                                      drop_levels = FALSE,
@@ -161,7 +167,13 @@ data_tabulate.grouped_df <- function(x,
   group_variables <- NULL
 
   # evaluate arguments
-  select <- .select_nse(select, x, exclude, ignore_case)
+  select <- .select_nse(select,
+    x,
+    exclude,
+    ignore_case,
+    regex = regex,
+    verbose = verbose
+  )
 
   # dplyr < 0.8.0?
   if (is.null(grps)) {
@@ -174,7 +186,7 @@ data_tabulate.grouped_df <- function(x,
 
   x <- as.data.frame(x)
   out <- list()
-  for (i in 1:length(grps)) {
+  for (i in seq_along(grps)) {
     rows <- grps[[i]]
     # save information about grouping factors
     if (!is.null(group_variables)) {
@@ -329,7 +341,7 @@ print_md.dw_data_tabulate <- function(x, big_mark = NULL, ...) {
 print.dw_data_tabulates <- function(x, big_mark = NULL, ...) {
   a <- attributes(x)
   if (!isTRUE(a$collapse) || length(x) == 1) {
-    for (i in 1:length(x)) {
+    for (i in seq_along(x)) {
       print(x[[i]], big_mark = big_mark, ...)
       if (i < length(x)) cat("\n")
     }
