@@ -281,13 +281,14 @@ degroup <- function(x,
   not_found <- setdiff(select, colnames(x))
 
   if (length(not_found) && isTRUE(verbose)) {
-    insight::print_color(
-      sprintf(
-        "%i variables were not found in the dataset: %s\n",
-        length(not_found),
-        paste0(not_found, collapse = ", ")
-      ),
-      color = "red"
+    message(
+      insight::format_message(
+        sprintf(
+          "%i variables were not found in the dataset: %s\n",
+          length(not_found),
+          paste0(not_found, collapse = ", ")
+        )
+      )
     )
   }
 
