@@ -123,7 +123,12 @@ skewness.numeric <- function(x,
 
   if (type == "2" && n < 3) {
     if (verbose) {
-      warning(insight::format_message("Need at least 3 complete observations for type-2-skewness. Using 'type=\"1\"' now."), call. = FALSE)
+      warning(
+        insight::format_message(
+          "Need at least 3 complete observations for type-2-skewness. Using 'type=\"1\"' now."
+        ),
+        call. = FALSE
+      )
     }
     type <- "1"
   }
@@ -263,7 +268,12 @@ kurtosis.numeric <- function(x,
 
   if (type == "2" && n < 4) {
     if (verbose) {
-      warning(insight::format_message("Need at least 4 complete observations for type-2-kurtosis Using 'type=\"1\"' now."), call. = FALSE)
+      warning(
+        insight::format_message(
+          "Need at least 4 complete observations for type-2-kurtosis Using 'type=\"1\"' now."
+        ),
+        call. = FALSE
+      )
     }
     type <- "1"
   }
@@ -419,8 +429,15 @@ summary.parameters_kurtosis <- function(object, test = FALSE, ...) {
   # convenience
   if (is.numeric(type)) type <- as.character(type)
 
-  if (is.null(type) || is.na(type) || !(type %in% c("1", "2", "3", "I", "II", "III", "classic", "SPSS", "SAS", "Minitab"))) {
-    warning(insight::format_message("'type' must be a character value from \"1\" to \"3\". Using 'type=\"2\"' now."), call. = FALSE)
+  if (is.null(type) ||
+    is.na(type) ||
+    !(type %in% c("1", "2", "3", "I", "II", "III", "classic", "SPSS", "SAS", "Minitab"))) {
+    warning(
+      insight::format_message(
+        "'type' must be a character value from \"1\" to \"3\". Using 'type=\"2\"' now."
+      ),
+      call. = FALSE
+    )
     type <- "2"
   }
 
