@@ -68,7 +68,13 @@ standardize.default <- function(x,
                                 include_response = TRUE,
                                 ...) {
   if (!insight::is_model(x)) {
-    warning(insight::format_message(paste0("Objects or variables of class '", class(x)[1], "' cannot be standardized.")), call. = FALSE)
+    warning(insight::format_message(
+      paste0(
+        "Objects or variables of class '",
+        class(x)[1],
+        "' cannot be standardized."
+      )
+    ), call. = FALSE)
     return(x)
   }
 
@@ -100,8 +106,12 @@ standardize.default <- function(x,
   }
 
   if (m_info$is_bayesian) {
-    warning(insight::format_message("Standardizing variables without adjusting priors may lead to bogus results unless priors are auto-scaled."),
-      call. = FALSE, immediate. = TRUE
+    warning(
+      insight::format_message(
+        "Standardizing variables without adjusting priors may lead to bogus results unless priors are auto-scaled."
+      ),
+      call. = FALSE,
+      immediate. = TRUE
     )
   }
 
@@ -149,7 +159,9 @@ standardize.default <- function(x,
   # because negative weights will cause errors in "update()"
   weight_variable <- insight::find_weights(x)
 
-  if (!is.null(weight_variable) && !weight_variable %in% colnames(data) && "(weights)" %in% colnames(data)) {
+  if (!is.null(weight_variable) &&
+    !weight_variable %in% colnames(data) &&
+    "(weights)" %in% colnames(data)) {
     data$.missing_weight <- data[["(weights)"]]
     colnames(data)[ncol(data)] <- weight_variable
     weight_variable <- c(weight_variable, "(weights)")
@@ -159,21 +171,21 @@ standardize.default <- function(x,
   random_group_factor <- insight::find_random(x, flatten = TRUE, split_nested = TRUE)
 
 
-
-
   ## ---- SUMMARY: TO Z OR NOT TO Z? ----
+
   dont_standardize <- c(resp, weight_variable, random_group_factor)
   do_standardize <- setdiff(colnames(data), dont_standardize)
 
   # can't std data$var variables
   if (any(doller_vars <- grepl("(.*)\\$(.*)", do_standardize))) {
     doller_vars <- colnames(data)[doller_vars]
-    warning(insight::format_message(
-      "Unable to standardize variables evaluated in the environment (i.e., not in `data`).",
-      "The following variables will not be standardizd:",
-      paste0(doller_vars, collapse = ", ")
-    ),
-    call. = FALSE
+    warning(
+      insight::format_message(
+        "Unable to standardize variables evaluated in the environment (i.e., not in `data`).",
+        "The following variables will not be standardizd:",
+        paste0(doller_vars, collapse = ", ")
+      ),
+      call. = FALSE
     )
     do_standardize <- setdiff(do_standardize, doller_vars)
     dont_standardize <- c(dont_standardize, doller_vars)
@@ -232,7 +244,12 @@ standardize.default <- function(x,
   }
 
   if (verbose && length(c(log_terms, sqrt_terms))) {
-    message(insight::format_message("Formula contains log- or sqrt-terms. See help(\"standardize\") for how such terms are standardized."))
+    message(
+      insight::format_message(
+        "Formula contains log- or sqrt-terms.",
+        "See help(\"standardize\") for how such terms are standardized."
+      )
+    )
   }
 
 
@@ -277,11 +294,12 @@ standardize.brmsfit <- function(x,
                                 ...) {
   data_std <- NULL # needed to avoid note
   if (insight::is_multivariate(x)) {
-    stop(insight::format_message(
-      "multivariate brmsfit models not supported.",
-      "As an alternative: you may standardize your data (and adjust your priors), and re-fit the model."
-    ),
-    call. = FALSE
+    stop(
+      insight::format_message(
+        "multivariate brmsfit models not supported.",
+        "As an alternative: you may standardize your data (and adjust your priors), and re-fit the model."
+      ),
+      call. = FALSE
     )
   }
 
@@ -361,7 +379,13 @@ standardize.mediate <- function(x,
         y_data_std = y_data_std, m_data_std = m_data_std
       )
     )
-    if (verbose) message(insight::format_message("Covariates' values have been rescaled to their standardized scales."))
+    if (verbose) {
+      message(
+        insight::format_message(
+          "Covariates' values have been rescaled to their standardized scales."
+        )
+      )
+    }
   }
 
   # if (is.numeric(y_data[[x$treat]]) || is.numeric(m_data[[x$treat]])) {
@@ -380,11 +404,12 @@ standardize.mediate <- function(x,
   # }
 
   if (verbose && !all(c(control.value, treat.value) %in% c(0, 1))) {
-    warning(insight::format_message(
-      "Control and treat values are not 0 and 1, and have not been re-scaled.",
-      "Interpret results with caution."
-    ),
-    call. = FALSE
+    warning(
+      insight::format_message(
+        "Control and treat values are not 0 and 1, and have not been re-scaled.",
+        "Interpret results with caution."
+      ),
+      call. = FALSE
     )
   }
 
@@ -453,11 +478,12 @@ standardize.biglm <- standardize.wbm
 .safe_to_standardize_response <- function(info, verbose = TRUE) {
   if (is.null(info)) {
     if (verbose) {
-      warning(insight::format_message(
-        "Unable to verify if response should not be standardized.",
-        "Response will be standardized."
-      ),
-      immediate. = TRUE, call. = FALSE
+      warning(
+        insight::format_message(
+          "Unable to verify if response should not be standardized.",
+          "Response will be standardized."
+        ),
+        immediate. = TRUE, call. = FALSE
       )
     }
     return(TRUE)
@@ -482,8 +508,12 @@ standardize.biglm <- standardize.wbm
 }
 
 #' @keywords internal
-.rescale_fixed_values <- function(val, cov_nm,
-                                  y_data, m_data, y_data_std, m_data_std) {
+.rescale_fixed_values <- function(val,
+                                  cov_nm,
+                                  y_data,
+                                  m_data,
+                                  y_data_std,
+                                  m_data_std) {
   if (cov_nm %in% colnames(y_data)) {
     temp_data <- y_data
     temp_data_std <- y_data_std
@@ -507,10 +537,11 @@ standardize.biglm <- standardize.wbm
     msg1 <- sprintf("Standardization of parameters not possible for models of class '%s'.", class)
   }
 
-  stop(insight::format_message(
-    msg1,
-    "Try instead to standardize the data (standardize(data)) and refit the model manually."
-  ),
-  call. = FALSE
+  stop(
+    insight::format_message(
+      msg1,
+      "Try instead to standardize the data (standardize(data)) and refit the model manually."
+    ),
+    call. = FALSE
   )
 }
